Name: zz_local_dns_cache
Summary: This package configures a host do local dns caching with bind
Version: 3
Release: 1.4
License: GPL
Group: Fermi
URL: http://fermilinux.fnal.gov/
Vendor: Fermilab
Packager: Pat Riehecky
BuildRequires: bash tar gzip findutils
Requires: bind bind-chroot
Requires: coreutils policycoreutils selinux-policy-targeted gawk chkconfig sed bash findutils diffutils
Obsoletes: caching-nameserver
Source0: zz_local_dns_cache.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}
BuildArch: noarch

%description
Installing this package will reconfigure named to run as a caching nameserver which will only allow connections from localhost. Your /etc/resolv.conf will be modified to call on localhost as primary nameserver.  The dhclient process will be configured to use this nameserver, if present.  Network Manager will be configured to use this nameserver, if present.

You should consider customizing the DNS server search list provided.  When removed you will be restored to using 131.225.0.254 SLF is used both on and off site.  If this is not what you want, you will need to customize these.

This package should work on SLF5 and SLF6.

NOTE: it disables dnsmasq to prevent conflicts, if you need dnsmasq do not install this package or figure out how to fix your site after it runs.

        This rpm makes the following assumptions:
        * If this is a fresh install of the rpm, named will be started
          and /etc/resolv.conf will be _replaced_ with the only nameserver
          being '127.0.0.1'
        * If this rpm is updated, it will ensure 'nameserver 127.0.0.1' is in
          /etc/resolv.conf
        * When removed, not upgraded, 131.225.0.254 is set instead
          unless there is another nameserver already listed.

        * Behavior specific to referenced packages will be execute whenever
          those packages are installed, updated, or removed.
          They consist of: bind NetworkManager dhclient dnsmasq nscd

        * On a bind update, bind will be restarted and the 'stub' zones
          will be reset.  These are the RFC1912 zones.
        * On a bind update, 'nameserver 127.0.0.1' will be added to
          /etc/resolv.conf if not already listed.
        * On a bind update, if nscd is running and chkconfig on, nscd will
          be restarted.

        * On a NetworkManager installation or when zz_local_dns_cache is
          installed for the first time, '127.0.0.1' will be configured as
          the only DNS server for all interfaces whose configuration matches
          /etc/sysconfig/network-scripts/ifcfg-* that are not 'ifcfg-lo'
          When removed, not upgraded, 131.225.0.254 is set instead

        * On a dhclient installation or when when zz_local_dns_cache is
          installed for the first time, '127.0.0.1' is added the the dhcp
          provided DNS server list.
          When removed, not upgraded, this setting is removed.

        * On a dnsmasq installation or when when zz_local_dns_cache is
          installed for the first time, dnsmasq is disabled.

        * On a dnsmasq installation or when when zz_local_dns_cache is
          installed for the first time, dnsmasq is configured to listen on
          127.0.0.1 if started with the defaul configuration file.
          It should function similarly to bind in this respect
          This feature was requested by people using libvirt/kvm.

        * On a nscd installation or update, if nscd is running and also
          chkconfig on nscd will be restarted.
          If zz_local_dns_cache is removed an if nscd is running and also
          chkconfig on nscd will be restarted.

%prep
%setup

%build

%install
mkdir -p %{buildroot}/var/named/chroot/etc/

find %{buildroot}/ -type f -exec chmod 644 {} \;
find %{buildroot}/ -type d -exec chmod 750 {} \;
install -m 640 zz_local_dns_cache.conf %{buildroot}/var/named/chroot/etc/

%files
/var/named/chroot/etc/zz_local_dns_cache.conf
%doc zz_local_dns_cache.conf
%doc zz_local_dns_cache-dhclient.conf
%doc named.rfc1912.zones
%doc named.empty
%doc named.localhost
%doc named.loopback
%doc README
%doc README.selinux

%clean
rm -rf %{buildroot}

###########################################################################

%post

# make sure named cannot write to master zones, we are in cache mode only!
setsebool -P named_write_master_zones 0 >/dev/null 2>&1  &

# I don't know why or how, but something keeps removing the named group
# from these files
chown root:named /usr/share/doc/%name-%version/*  >/dev/null 2>&1   &

# make sure our chroot is where we expect it to be
mkdir -p /var/named/chroot/etc/ &

# let things catch up
wait

# this is a fresh install
if [[ $1 -eq 1 ]]; then
    # start at boot
    chkconfig named on >/dev/null 2>&1   &

    # disable dnsmasq more permenantly
    chkconfig dnsmasq off >/dev/null 2>&1  &
fi

###########################################################################

%postun
# if this is an uninstall only (not an upgrade)
if [[ $1 -eq 0 ]]; then

    rm -f /etc/zz_local_dns_cache.conf   &

    # if named is using the provided config, deconfigure named
    if [[ `readlink /var/named/chroot/etc/named.conf | xargs -i basename {}` == "zz_local_dns_cache.conf" ]]; then
        service named stop   >/dev/null 2>&1 
        chkconfig named off  >/dev/null 2>&1    &
        rm -f /var/named/chroot/etc/named.conf  &
    fi

    # if named is using the provided config, deconfigure named
    if [[ `readlink /etc/named.conf | xargs -i basename {}` == "zz_local_dns_cache.conf" ]]; then
        rm -f /etc/named.conf  &
    fi

    # make sure /etc/resolv.conf still works after removal
    TMP=`mktemp`
    # remove all the lines we added
    grep -v "127.0.0.1" /etc/resolv.conf |grep -v '# Generated by zz_local_dns_cache' | grep -v '# lookups forwarded to' | grep -v '#nameserver 131.225.0.254' > $TMP
    grep '^nameserver' $TMP >/dev/null 2>&1
    if [[ $? -ne 0 ]]; then
        echo "nameserver 131.225.0.254" >> $TMP
    fi
    cat $TMP > /etc/resolv.conf
    rm -f $TMP    &
    restorecon /etc/resolv.conf >/dev/null 2>&1 &

    # let things catch up
    wait
fi

###########################################################################

%triggerin -- bind
# Whenever bind is updated we need to make sure that our config still works
# Most of these operations are '&' so that the kernel elevator can optimize
# them as much of this IO happens over a limited disk range, this should
# help reduce the time spent on disk activites

ps -fu named |grep -v grep |grep named >/dev/null 2>&1
if [[ $? -eq 0 ]]; then
    RUNNING_NAMED=0
    # cleanup any running named
    service named stop >/dev/null 2>&1

    # don't know if this is running or installed, but in a second we are
    # going to turn on bind so this can't be running at that time or weirdness
    service dnsmasq stop  >/dev/null 2>&1  &
else
    RUNNING_NAMED=1
fi

chkconfig --list named 2>/dev/null |grep :on >/dev/null 2>&1
if [[ $? -eq 0 ]]; then
    NAMED_CHKCONFIG=0
else
    NAMED_CHKCONFIG=1
fi

# I don't know why or how, but something keeps removing the named group
# from these files
chown root:named /var/named/chroot/etc/zz_local_dns_cache.conf  >/dev/null 2>&1   &

# make sure my selinux context is right
chcon -t named_conf_t /var/named/chroot/etc/zz_local_dns_cache.conf >/dev/null 2>&1   &
chcon -u system_u /var/named/chroot/etc/zz_local_dns_cache.conf     >/dev/null 2>&1   &
chcon -r object_r /var/named/chroot/etc/zz_local_dns_cache.conf     >/dev/null 2>&1   &

# link the config file from the chroot, so its easy to find
if [[ ! -f /etc/zz_local_dns_cache.conf ]]; then
    ln -s /var/named/chroot/etc/zz_local_dns_cache.conf /etc/zz_local_dns_cache.conf  &
fi

# make the new config file the named.conf master
if [[ -e /var/named/chroot/etc/named.conf ]]; then
    if [[ -L /var/named/chroot/etc/named.conf ]] ; then
        rm -f /var/named/chroot/etc/named.conf
    else
        mv -f /var/named/chroot/etc/named.conf /var/named/chroot/etc/named.conf.rpmbak
    fi
fi
cd /var/named/chroot/etc/ ; ln -s zz_local_dns_cache.conf named.conf

# make sure my selinux context is right
chcon -h -t named_conf_t /var/named/chroot/etc/named.conf >/dev/null 2>&1   &
chcon -h -u system_u /var/named/chroot/etc/named.conf     >/dev/null 2>&1   &
chcon -h -r object_r /var/named/chroot/etc/named.conf     >/dev/null 2>&1   &

# make sure we have the needed rfc zones in the chroot
# different between 5 and 6, using the 6 config as its fine on 5
if [[ ! -f /var/named/chroot/etc/named.rfc1912.zones ]]; then
    cp -p /usr/share/doc/%name-%version/named.rfc1912.zones /var/named/chroot/etc/
    chmod 640 /var/named/chroot/etc/named.rfc1912.zones
    chown root:named /var/named/chroot/etc/named.rfc1912.zones
fi

# make sure my selinux context is right
chcon -t named_conf_t /var/named/chroot/etc/named.rfc1912.zones >/dev/null 2>&1   &
chcon -u system_u /var/named/chroot/etc/named.rfc1912.zones     >/dev/null 2>&1   &
chcon -r object_r /var/named/chroot/etc/named.rfc1912.zones     >/dev/null 2>&1   &

# try a hard link first
if [[ ! -f /etc/named.rfc1912.zones ]]; then
    ln /var/named/chroot/etc/named.rfc1912.zones /etc/ >/dev/null 2>&1
    if [[ ! -f /etc/named.rfc1912.zones ]]; then
        ln -s /var/named/chroot/etc/named.rfc1912.zones /etc/   &
    fi
fi

# 5.x needs these copied in
for stubzone in named.empty named.localhost named.loopback; do
    if [[ ! -e /var/named/chroot/var/named/$stubzone ]]; then
        cp -p /usr/share/doc/%name-%version/$stubzone /var/named/chroot/var/named/
        chown root:named /var/named/chroot/var/named/$stubzone  &
        chmod 640 /var/named/chroot/var/named/$stubzone         &

        # make sure my selinux context is right
        chcon -t named_zone_t /var/named/chroot/var/named/$stubzone >/dev/null 2>&1  &
        chcon -u system_u /var/named/chroot/var/named/$stubzone     >/dev/null 2>&1  &
        chcon -r object_r /var/named/chroot/var/named/$stubzone     >/dev/null 2>&1  &
    fi
done

# let things catch up
wait

# check for if this is a fresh install of bind
# and not an update to zz_local_dns_cache
FRESH=0
if [[ $2 -eq 1 ]]; then  # bind count
    FRESH=1
fi
if [[ $1 -eq 1 ]]; then  # zz_local_dns_cache count
    FRESH=1
elif [[ $1 -ne 1 ]]; then # update in progress
    FRESH=0
fi

RESTART_NSCD=0
# this is a fresh install of bind or zz_local_dns_cache
if [[ $FRESH -eq 1 ]]; then

    # Start our newly configured named
    service named restart >/dev/null 2>&1

    # replace /etc/resolv.conf with references to new name server
    TMP=`mktemp`
    echo "# Generated by zz_local_dns_cache" > $TMP
    grep "search " /etc/resolv.conf >> $TMP
    echo "nameserver 127.0.0.1" >> $TMP
    echo "# lookups forwarded to" >> $TMP
    echo "#nameserver 131.225.0.254" >> $TMP
    cat $TMP > /etc/resolv.conf
    rm -f $TMP
    # we touched /etc/resolv.conf, if we care about nscd we must
    # restart it or else things break in bad, hard to find ways
    RESTART_NSCD=1

# this is not a fresh install
else
    if [[ $RUNNING_NAMED -eq 0 ]]; then
        if [[ $NAMED_CHKCONFIG -eq 0 ]]; then
            # this should be present or there is no point in running it
            grep '^nameserver 127.0.0.1' /etc/resolv.conf >/dev/null 2>&1
            if [[ $? -eq 1 ]]; then
                echo "nameserver 127.0.0.1" >> /etc/resolv.conf
                # we touched /etc/resolv.conf, if we care about nscd we must
                # restart it or else things break in bad, hard to find ways
                RESTART_NSCD=1
            fi
            service named restart >/dev/null 2>&1
        fi
    fi
fi

# this is conditionally run whenever we touched /etc/resolv.conf
# and nscd is running and nscd is chkconfig on
if [[ $RESTART_NSCD -eq 1 ]]; then
    if [[ $(ps -fu nscd 2>/dev/null |wc -l) -eq 2 ]]; then
        # is running
        NSCD_RUNNING=0
    else
        NSCD_RUNNING=1
    fi

    chkconfig --list named 2>/dev/null |grep :on >/dev/null 2>&1
    if [[ $? -eq 0 ]]; then
        # is chkconfig on
        NSCD_CHKCONFIG=0
    else
        NSCD_CHKCONFIG=1
    fi

    if [[ $NSCD_RUNNING -eq 0 ]]; then
        if [[ $NSCD_CHKCONFIG -eq 0 ]]; then
            # only if running _and_ chkconfig on
            # restart runs a HUP, we need a real stop/start
            service nscd stop >/dev/null 2>&1
            service nscd start >/dev/null 2>&1
        fi
    fi
fi
restorecon /etc/resolv.conf >/dev/null 2>&1

###########################################################################

%triggerin -- NetworkManager
# check for if this is a fresh install of NetworkManager
# and not an update to zz_local_dns_cache
FRESH=0
if [[ $2 -eq 1 ]]; then  # NetworkManager count
    FRESH=1
fi
if [[ $1 -eq 1 ]]; then  # zz_local_dns_cache count
    FRESH=1
elif [[ $1 -ne 1 ]]; then # update in progress
    FRESH=0
fi

# this is a fresh install of NetworkManager
# once this is done we should never do it again
if [[ $FRESH -eq 1 ]]; then
    for eth in `ls /etc/sysconfig/network-scripts/ifcfg-* 2>/dev/null | grep -v ifcfg-lo`; do

        # does NetworkManager control this interface
        grep -v '#' $eth |grep 'NM_CONTROLLED='|grep -i yes >/dev/null 2>&1
        if [[ $? -ne 0 ]]; then
            # if this isn't controlled skip it
            continue
        fi

        grep -v '#' $eth |grep 'DNS1=127.0.0.1' >/dev/null 2>&1
        if [[ $? -eq 1 ]]; then
            TMP=`mktemp`
            # remove the DNS control lines
            grep -v "^DNS" $eth |grep -v "PEERDNS=" | sort -u  > $TMP
            # put them back in, but commented out
            grep    "^DNS" $eth | sort -u | xargs -i echo "#{}" >> $TMP
            grep    "PEERDNS=" $eth | sort -u | xargs -i echo "#{}" >> $TMP
            # add our control lines
            echo "DNS1=127.0.0.1" >> $TMP
            echo "PEERDNS='no'" >> $TMP
            # everyone likes sort!
            cat $TMP | sort -u > $eth
            # clean up
            rm -f $TMP  &
            restorecon $eth >/dev/null 2>&1 &
        fi
    done
    wait   # let things catch up
fi

%triggerun -- NetworkManager
# if this is an uninstall only (not an upgrade) of zz_local_dns_cache
# remove all our changes
if [[ $1 -eq 0 ]]; then
    for eth in `ls /etc/sysconfig/network-scripts/ifcfg-* 2>/dev/null | grep -v ifcfg-lo`; do
        # don't care if we are controlled by NetworkManager
        # in a second this wont work at all, pull it out!
        grep 'DNS1=127.0.0.1' $eth >/dev/null 2>&1
        if [[ $? -eq 0 ]]; then
            TMP=`mktemp`
            # grab everything that isn't DNS or PEERDNS
            #  and save it
            grep -v "^DNS" $eth | grep -v "PEERDNS=" | sort -u > $TMP
            # put PEERDNS back to 'yes'
            echo "PEERDNS='yes'" >> $TMP
            # grab every DNS line that isn't 127.0.0.1
            grep -v 127.0.0.1 $eth | grep "^DNS" >/dev/null
            if [[ $? -ne 0 ]]; then
                # if we've got no DNS on file add some
                echo "DNS1=131.225.0.254" >> $TMP
            else
                # preserve the order of whatever you've got but
                # make sure there are no gaps
                count=0
                for SRV in `grep -v 127.0.0.1 $eth | grep "^DNS" | sort`; do
                    IP=`echo $SRV | cut -d '=' -f2`
                    count=$(expr $count + 1)
                    echo "DNS${count}=$IP" >> $TMP
                done
            fi
            cat $TMP | sort -u > $eth
            rm -f $TMP  &
            restorecon $eth >/dev/null 2>&1 &
        fi
    done
    wait   # let things catch up
fi

###########################################################################

%triggerin -- dhclient
# check for if this is a fresh install of dhclient
# and not an update to zz_local_dns_cache
FRESH=0
if [[ $2 -eq 1 ]]; then  # dhclient count
    FRESH=1
fi
if [[ $1 -eq 1 ]]; then  # zz_local_dns_cache count
    FRESH=1
elif [[ $1 -ne 1 ]]; then # update in progress
    FRESH=0
fi


# this is a fresh install of dhclient
# once this is done we should never do it again
if [[ $FRESH -eq 1 ]]; then

    SLFVERSION=0
    for rel_string in `cat /etc/redhat-release`; do
        ver=`echo $rel_string | cut -d'.' -f1`
        if [[ $ver -eq 5 ]]; then
            SLFVERSION=5
        elif [[ $ver -eq 6 ]]; then
            SLFVERSION=6
        elif [[ $ver -eq 7 ]]; then
            SLFVERSION=7
        fi
    done
    if [[ "$SLFVERSION" == '0' ]]; then
        exit 0
    fi

    DHCP_CONFIG_PATH=''
    if [[ "$SLFVERSION" == '5' ]]; then
        DHCP_CONFIG_PATH='/etc'
     elif [[ "$SLFVERSION" == '6' ]]; then
        DHCP_CONFIG_PATH='/etc/dhcp'
     else
        exit 0
    fi

    if [[ "x$DHCP_CONFIG_PATH" != 'x' ]]; then
        if [[ -e $DHCP_CONFIG_PATH/dhclient.conf ]]; then
        # does dhclient.conf already have all the lines in it?
        # odds are no, but may as well check first
            diff /usr/share/doc/%name-%version/zz_local_dns_cache-dhclient.conf $DHCP_CONFIG_PATH/dhclient.conf | grep '>' >/dev/null 2>&1
            if [[ $? -ne 1 ]]; then
                # looks like there was something in the file already
                cat /usr/share/doc/%name-%version/zz_local_dns_cache-dhclient.conf >> $DHCP_CONFIG_PATH/dhclient.conf
            fi
        else
            cp /usr/share/doc/%name-%version/zz_local_dns_cache-dhclient.conf $DHCP_CONFIG_PATH/dhclient.conf
        fi
    fi
fi

# always a good idea to run restorecon, it wont hurt on missing files
restorecon /etc/dhclient.conf >/dev/null 2>&1       &
restorecon /etc/dhcp/dhclient.conf >/dev/null 2>&1  &

# let things catch up
wait

%triggerun -- dhclient
# if this is an uninstall only (not an upgrade) of zz_local_dns_cache
# remove all our changes
if [[ $1 -eq 0 ]]; then

    SLFVERSION=0
    for rel_string in `cat /etc/redhat-release`; do
        ver=`echo $rel_string | cut -d'.' -f1`
        if [[ $ver -eq 5 ]]; then
            SLFVERSION=5
        elif [[ $ver -eq 6 ]]; then
            SLFVERSION=6
        elif [[ $ver -eq 7 ]]; then
            SLFVERSION=7
        fi
    done
    if [[ "$SLFVERSION" == '0' ]]; then
        exit 0
    fi

    DHCP_CONFIG_PATH=''
    if [[ "$SLFVERSION" == '5' ]]; then
        DHCP_CONFIG_PATH='/etc'
     elif [[ "$SLFVERSION" == '6' ]]; then
        DHCP_CONFIG_PATH='/etc/dhcp'
     else
        exit 0
    fi

    # did you customize this?
    diff /usr/share/doc/%name-%version/zz_local_dns_cache-dhclient.conf $DHCP_CONFIG_PATH/dhclient.conf | grep '>' >/dev/null 2>&1
    if [[ $? -ne 1 ]]; then
        # save the modified file
        mv -f $DHCP_CONFIG_PATH/dhclient.conf $DHCP_CONFIG_PATH/dhclient.conf.rpmsave
        # remove any '127.0.0.1' lines
        cat $DHCP_CONFIG_PATH/dhclient.conf.rpmsave | grep -v 127.0.0.1 > $DHCP_CONFIG_PATH/dhclient.conf
    else
        # if it is identical to the one we pushed out remove it
        rm -f $DHCP_CONFIG_PATH/dhclient.conf
    fi
fi

# always a good idea to run restorecon, it wont hurt on missing files
restorecon /etc/dhclient.conf >/dev/null 2>&1       &
restorecon /etc/dhcp/dhclient.conf >/dev/null 2>&1  &

# let things catch up
wait

###########################################################################

%triggerin -- dnsmasq
# check for if this is a fresh install of dnsmasq
# and not an update to zz_local_dns_cache
FRESH=0
if [[ $2 -eq 1 ]]; then  # dhclient count
    FRESH=1
fi
if [[ $1 -eq 1 ]]; then  # dnsmasq count
    FRESH=1
elif [[ $1 -ne 1 ]]; then # update in progress
    FRESH=0
fi


# this is a fresh install of dnsmasq
# once this is done we should never do it again
if [[ $FRESH -eq 1 ]]; then
    chkconfig dnsmasq off # since we chkconfig'd bind on we should turn this off

    sed -i'.rpmbak' \
        -e "s/#no-dhcp-interface=.*/no-dhcp-interface=lo/"  \
        -e "s/#listen-address=.*/listen-address=127.0.0.1/" \
        -e "s/#no-resolv.*/no-resolv\ndomain=fnal.gov\nserver=131.225.0.254\n/"   \
    /etc/dnsmasq.conf

    restorecon /etc/dnsmasq.conf >/dev/null 2>&1
fi

%triggerun -- dnsmasq
# if this is an uninstall only (not an upgrade) of zz_local_dns_cache
# remove all our changes
if [[ $1 -eq 0 ]]; then
    sed -i'.rpmsave'      \
        -e "s/^no-dhcp-interface=\(.*\)/#no-dhcp-interface=\1/"  \
        -e "s/^listen-address=\(.*\)/#listen-address\1/" \
        -e "s/^no-resolv/#no-resolv/" \
        -e "s/^domain=fnal.gov//" \
        -e "s/^server=131.225.0.254//" \
    /etc/dnsmasq.conf

    restorecon /etc/dnsmasq.conf >/dev/null 2>&1
fi

###########################################################################

%triggerin -- nscd
# if nscd is here it is simpler just to kick it than to run
# the list of times we must restart it
if [[ $(ps -fu nscd 2>/dev/null |wc -l) -eq 2 ]]; then
    NSCD_RUNNING=0
else
    NSCD_RUNNING=1
fi

chkconfig --list nscd 2>/dev/null |grep :on >/dev/null 2>&1
if [[ $? -eq 0 ]]; then
    NSCD_CHKCONFIG=0
else
    NSCD_CHKCONFIG=1
fi

if [[ $NSCD_RUNNING -eq 0 ]]; then
    if [[ $NSCD_CHKCONFIG -eq 0 ]]; then
        # restart runs a HUP, we need a real stop/start
        service nscd stop >/dev/null 2>&1
        service nscd start >/dev/null 2>&1
    fi
fi

###########################################################################

%changelog
* Wed Aug 10 2016 Pat Riehecky <riehecky@fnal.gov> 3-1.4
- Removed 8.8.8.8 from the DNS server list

* Fri Sep 28 2012 Pat Riehecky <riehecky@fnal.gov> 3-1.3.1
- better checks for upgrades of various things
- clearer doc on what triggers are running off of which events and why
- fixed the NetworkManager scripts to only modify controlled interfaces

* Fri Sep 28 2012 Pat Riehecky <riehecky@fnal.gov> 3-1.3
- yet another update to the resolv.conf preservation
- fixed the NetworkManager scripts so that they correctly clean up upon removal

* Fri Aug 10 2012 Pat Riehecky <riehecky@fnal.gov> 3-1.2
- nscd process searches now seach by process ownership.
- resolv.conf settings are more accuratly preserved.

* Wed Jul 18 2012 Pat Riehecky <riehecky@fnal.gov> 3-1.1
- Yet another check on nscd, this really shouldn't start it unless you want it
- Standardized the trigger interface a bit further
- Updated grep checks, thanks Steve Timm

* Fri Jun 15 2012 Pat Riehecky <riehecky@fnal.gov> 3-1
- moved most of the config work to a trigger on 'bind'
  this way the config is validated on each update.  This should
  keep things working longer through updates
- made nscd restart silent (oops)

* Thu Jan 19 2012 Pat Riehecky <riehecky@fnal.gov> 3-0.3
- clean up stray /etc/named.conf link
- added nscd restart
- made smarter about when it starts bind and when it doesn't

* Thu Jan 12 2012 Pat Riehecky <riehecky@fnal.gov> 3-0.2
- try and hardlink /etc/named.rfc1912.zones before soft link
- moved the blocks which actually start the named server to the 'fresh install only' space
- made the /etc/resolv.conf edit smarter so that it doesn't do anything if named isn't running

* Thu Dec 8 2011 Pat Riehecky <riehecky@fnal.gov> 3-0.1
- fixed a minor chmod problem
- switched search from /etc/sysconfig/network-scripts/ifcfg-eth* to /etc/sysconfig/network-scripts/ifcfg-*|grep -v ifcfg-lo to account for strangly named cards

* Wed Nov 9 2011 Pat Riehecky <riehecky@fnal.gov> 3-0.0
- Almost totally re-written
- Moved NetworkManager to trigger
- Moved dhclient to trigger
- Added dnsmasq trigger
  this rpm enables bind, but if you want instead dnsmasq it should be configured
- Now requires selinux packages, selinux enforcement is however optional
  more info in README.selinux
- Using links to help make it obvious which file bind is reading
- Modified config to use views to help reduce possible non localhost use in bind
- Switched from a dynamic config to a static one for deploy and copy to 'doc'
  it is configured after the style of SLF5 caching-nameserver but with
  the approach from SLF6 bind.  It ballences security and readibility.
- Obsolete caching-nameserver for 5.x its not in 6.x and integration was messy
- Set sane looking defaults rather than ad-hoc creation of forwarder list
   + 131.225.0.254
   + 8.8.8.8

* Mon May 23 2011 Jason Harrington <jason@fnal.gov> 2.0-2
- Fixed bugs dealing with NetworkManager comments in /etc/resolv.conf
- Added default DNS forwarder when no nameserver list found
- Added eth0-specific domain-name-server prepend for use with NetworkManager
- Added post-uninstall bits to undo dhclient tweaks

* Thu May 19 2011 Jason Harrington <jason@fnal.gov> 2.0-1
- Updated for use with SL(F)6x

*Fri Jan 05 2007 Troy Dawson <dawson@fnal.gov> 1.0-2
- Added post and postun to add 127.0.0.1 to the resolv.conf

*Fri Jan 05 2007 Troy Dawson <dawson@fnal.gov> 1.0-1
- First pass, looks good
